@@ -95,9 +95,7 @@ mods = ('clu',
         'clu.abstract',
         'clu.constants.consts',
         'clu.constants.polyfills',
-        'clu.config.base',
         'clu.config.codecs',
-        'clu.config.settings',
         'clu.config.ns',
         'clu.csv',
         'clu.fs.appdirectories',
